@@ -2,7 +2,7 @@
 ## Author: Sunthud Pornprasertmanit
 # Description: Automatically accounts for auxiliary variable in full information maximum likelihood
 
-setClass("lavaanStar", contains = "lavaan", representation(nullfit = "vector", imputed="list"), prototype(nullfit=c(chi=0,df=0), imputed=list()))
+setClass("lavaanStar", contains = "lavaan", representation(nullfit = "vector", imputed="list", auxNames="vector"), prototype(nullfit=c(chi=0,df=0), imputed=list(), auxNames = ""))
 
 setMethod("inspect", "lavaanStar",
 function(object, what="free") {
@@ -20,6 +20,9 @@ function(object, what="free") {
 		} else {
 			stop("This method did not made by multiple imputation.")
 		}
+	} else if(what == "aux" ||
+              what == "auxiliary") {
+		print(object@auxNames)
 	} else {
 		getMethod("inspect", "lavaan")(object, what=what)
 	}
@@ -57,17 +60,57 @@ auxiliary <- function(model, aux, fun, ...) {
 	args$missing <- "fiml"
 	
 	if(is(model, "lavaan")) {
-		if(!fit@Options$meanstructure) stop("The lavaan fitted model must evaluate the meanstructure. Please re-fit the lavaan object again with 'meanstructure=TRUE'")
+		if(!model@Options$meanstructure) stop("The lavaan fitted model must evaluate the meanstructure. Please re-fit the lavaan object again with 'meanstructure=TRUE'")
 		model <- model@ParTable
 	} else if(!(is.list(model) && ("lhs" %in% names(model)))) {
 		fit <- do.call(fun, c(list(model=model, do.fit=FALSE), args))
 		model <- fit@ParTable
 	}
-	
+	model <- model[setdiff(1:length(model), which(names(model) == "start"))]
+
 	if(any(model$exo == 1)) {
 		stop("All exogenous variables (covariates) must be treated as endogenous variables by the 'auxiliary' function (fixed.x = FALSE).")
 	}
+
+	auxResult <- craftAuxParTable(model = model, aux = aux, ...)
+	if(checkOrdered(args$data, auxResult$indName, ...)) {
+		stop("The analysis model or the analysis data have ordered categorical variables. The auxiliary variable feature is not available for the models for categorical variables with the weighted least square approach.")
+	}
 	
+	args$model <- auxResult$model
+	result <- do.call(fun, args)
+	
+	codeNull <- nullAuxiliary(aux, auxResult$indName, NULL, any(model$op == "~1"), max(model$group))
+	resultNull <- lavaan::lavaan(codeNull, ...)
+	result <- as(result, "lavaanStar")
+	fit <- lavaan::fitMeasures(resultNull)
+	name <- names(fit)
+	fit <- as.vector(fit)
+	names(fit) <- name
+	result@nullfit <- fit
+	result@auxNames <- aux
+	return(result)
+}
+
+checkOrdered <- function(dat, varnames, ...) {
+	ord <- list(...)$ordered
+	if(is.null(ord)) { 
+		ord <- FALSE
+	} else {
+		ord <- TRUE
+	}
+	if(is.null(dat)) {
+		orderedVar <- FALSE
+	} else {
+		orderedVar <- sapply(dat[,varnames], function(x) "ordered" %in% is(x))
+	}
+	any(c(ord, orderedVar))
+}
+
+craftAuxParTable <- function(model, aux, ...) {
+	constraintLine <- model$op %in% c("==", ":=", ">", "<")
+	modelConstraint <- lapply(model, "[", constraintLine)
+	model <- lapply(model, "[", !constraintLine)
 	facName <- NULL
 	indName <- NULL
 	singleIndicator <- NULL
@@ -79,35 +122,48 @@ auxiliary <- function(model, aux, fun, ...) {
 		model$lhs <- gsub(singleIndicator[i], facSingleIndicator[i], model$lhs)
 		model$rhs <- gsub(singleIndicator[i], facSingleIndicator[i], model$rhs)
 	}
-		
 	ngroups <- max(model$group)
-		if(!is.null(singleIndicator) && length(singleIndicator) != 0) model <- attachPT(model, facSingleIndicator, "=~", singleIndicator, ngroups, fixed = TRUE, ustart = 1, expand = FALSE)
-		if(!is.null(singleIndicator) && length(singleIndicator) != 0) model <- attachPT(model, singleIndicator, "~~", singleIndicator, ngroups, fixed = TRUE, ustart = 0, expand = FALSE)
+	if(!is.null(singleIndicator) && length(singleIndicator) != 0) model <- attachPT(model, facSingleIndicator, "=~", singleIndicator, ngroups, fixed = TRUE, ustart = 1, expand = FALSE)
+	if(!is.null(singleIndicator) && length(singleIndicator) != 0) model <- attachPT(model, singleIndicator, "~~", singleIndicator, ngroups, fixed = TRUE, ustart = 0, expand = FALSE)
+	if(!is.null(singleIndicator) && length(singleIndicator) != 0) model <- attachPT(model, singleIndicator, "~1", "", ngroups, fixed = TRUE, ustart = 0, expand = FALSE)
 	if(is.null(indName) || length(indName) == 0) {
 		faux <- paste0("f", aux)
 		model <- attachPT(model, faux, "=~", aux, ngroups, fixed = TRUE, ustart = 1, expand = FALSE)
 		model <- attachPT(model, aux, "~~", aux, ngroups, fixed = TRUE, ustart = 0, expand = FALSE)
 		model <- attachPT(model, facSingleIndicator, "~~", faux, ngroups)
 		model <- attachPT(model, faux, "~~", faux, ngroups, symmetric=TRUE)
-		if(any(model$op == "~1")) model <- attachPT(model, faux, "~1", "", ngroups)
+		if(any(model$op == "~1")) {
+			model <- attachPT(model, faux, "~1", "", ngroups)
+			model <- attachPT(model, aux, "~1", "", ngroups, fixed = TRUE, ustart = 0, expand = FALSE)
+		}
 	} else {
 		if(!is.null(indName) && length(indName) != 0) model <- attachPT(model, indName, "~~", aux, ngroups)
 		model <- attachPT(model, aux, "~~", aux, ngroups, symmetric=TRUE, useUpper=TRUE)
 		if(!is.null(singleIndicator) && length(singleIndicator) != 0) model <- attachPT(model, facSingleIndicator, "=~", aux, ngroups)
 		if(any(model$op == "~1")) model <- attachPT(model, aux, "~1", "", ngroups)
 	}
-	args$model <- model
-	result <- do.call(fun, args)
-	
-	codeNull <- nullAuxiliary(aux, union(indName, singleIndicator), NULL, any(model$op == "~1"), max(model$group))
-	resultNull <- lavaan(codeNull, ...)
-	result <- as(result, "lavaanStar")
-	fit <- fitMeasures(resultNull)
-	name <- names(fit)
-	fit <- as.vector(fit)
-	names(fit) <- name
-	result@nullfit <- fit
-	return(result)
+	model <- attachConstraint(model, modelConstraint)
+
+	list(model = model, indName = union(indName, singleIndicator))
+}
+
+attachConstraint <- function(pt, con) {
+	len <- length(con$id)
+	if(len > 0) {
+		pt$id <- c(pt$id, (max(pt$id)+1):(max(pt$id)+len))
+		pt$lhs <- c(pt$lhs, con$lhs)
+		pt$op <- c(pt$op, con$op)
+		pt$rhs <- c(pt$rhs, con$rhs)
+		pt$user <- c(pt$user, con$user)
+		pt$group <- c(pt$group, con$group)
+		pt$free <- c(pt$free, con$free)
+		pt$ustart <- c(pt$ustart, con$ustart)
+		pt$exo <- c(pt$exo, con$exo)
+		pt$label <- c(pt$label, con$label)
+		pt$eq.id <- c(pt$eq.id, con$eq.id)
+		pt$unco <- c(pt$unco, con$unco)
+	}
+	pt
 }
 
 attachPT <- function(pt, lhs, op, rhs, ngroups, symmetric=FALSE, exo=FALSE, fixed=FALSE, useUpper=FALSE, ustart = NA, expand = TRUE, diag = TRUE) {
