@@ -52,10 +52,22 @@ runMI <- function(model, data, m, miArgs=list(), chi="all", miPackage="Amelia",
 	template <- do.call(fun, out)
 
     imputed.results.l <- suppressWarnings(lapply(imputed.l, runlavaanMI, syntax=model, fun=fun, ...))
-    
 	converged.l <- sapply(imputed.results.l, function(x) x@Fit@converged)
+	
+	coefAll <- sapply(imputed.results.l, function(x) x@Fit@est)
 	seAll <- sapply(imputed.results.l, function(x) x@Fit@se)
-	converged.l <- converged.l & apply(seAll, 2, function(x) all(x >= 0))
+	partableImp <- lavaan::partable(imputed.results.l[[1]])
+	posVar <- (partableImp$op == "~~") & (partableImp$lhs == partableImp$rhs)
+	convergedtemp <- converged.l
+	properSE <- apply(seAll, 2, function(x) all(x >= 0) & !(all(x == 0)))
+	properVariance <- apply(coefAll[posVar, ,drop=FALSE], 2, function(x) all(x >= 0))
+	converged.l <- converged.l & properSE & properVariance
+	if(sum(converged.l) < 2) {
+		tab <- cbind(convergedtemp, properSE, properVariance, converged.l)
+		colnames(tab) <- c("1. Convergence", "2. Proper SE", "3. Proper Variance Estimate", "Used for pooling")
+		print(tab)
+		stop("Please increase the number of imputations. The number of convergent replications is less than or equal to 1. See the details above.")
+	}
 	
 	mOriginal <- m
 	m <- sum(converged.l)
@@ -66,7 +78,6 @@ runMI <- function(model, data, m, miArgs=list(), chi="all", miPackage="Amelia",
 	se <- sapply(imputed.results.l, function(x) x@Fit@se)
 	Sigma.hat <- lapply(imputed.results.l, function(object) object@Fit@Sigma.hat)
     Mu.hat <- lapply(imputed.results.l, function(object) object@Fit@Mu.hat)
-	
 	meanSigmaHat <- list()
 	meanMuHat <- list()
 	for(g in seq_len(template@SampleStats@ngroups)) {
@@ -77,18 +88,17 @@ runMI <- function(model, data, m, miArgs=list(), chi="all", miPackage="Amelia",
 	}
 	template@Fit@Sigma.hat <- meanSigmaHat
 	template@Fit@Mu.hat <- meanMuHat
-	
-	
 	comb.results <- miPoolVector(t(coefs),t(se), m)
 	template@Fit@est <- comb.results$coef
 	template@Fit@se <- comb.results$se
 	template@Fit@x <- comb.results$coef[comb.results$se != 0]
 	template@Model <- imposeGLIST(template@Model, comb.results$coef, template@ParTable)
 	
-	fmi.results <- cbind(parameterEstimates(template)[,1:3], group=template@ParTable$group, fmi1 = comb.results[[3]], fmi2 = comb.results[[4]])
+	fmi.results <- cbind(lavaan::parameterEstimates(template)[,1:3], group=template@ParTable$group, fmi1 = comb.results[[3]], fmi2 = comb.results[[4]])
 
 	fit <- imputed.results.l[[1]]@Fit@test
 	df <- fit[[1]]$df
+  if (df == 0) chi <- "none" # for saturated models, no model fit available
 	chi1 <- sapply(imputed.results.l, function(x) x@Fit@test[[1]]$stat)
 
 	if(any(template@Data@ov$type == "ordered") | (length(fit) > 1)) {
@@ -110,7 +120,7 @@ runMI <- function(model, data, m, miArgs=list(), chi="all", miPackage="Amelia",
 	} else {
 		fit[[1]]$stat.group <- rowMeans(sapply(imputed.results.l, function(x) x@Fit@test[[1]]$stat.group))
 	}
-	nullModel <- partable(lavaan:::independence.model.fit(template))
+	nullModel <- lavaan::lav_partable_independence(template)
     null.results <- suppressWarnings(lapply(imputed.l, runlavaanMI, syntax=nullModel, fun=fun, ...))
 
 	convergedNull.l <- sapply(null.results, function(x) x@Fit@converged)
@@ -205,7 +215,7 @@ runMI <- function(model, data, m, miArgs=list(), chi="all", miPackage="Amelia",
     ## HACK! YR
     templateNull@Fit@converged <- TRUE ### ! to trick fitMeasures
     ## 
-	notused <- capture.output(fitVec <- suppressWarnings(fitMeasures(templateNull)))
+	notused <- capture.output(fitVec <- suppressWarnings(lavaan::fitMeasures(templateNull)))
 	name <- names(fitVec)
 	fitVec <- as.vector(fitVec)
 	names(fitVec) <- name
@@ -237,48 +247,14 @@ runlavaanMI <- function(MIdata, syntax, fun, ...) {
 	out <- c(out, list(...))
 	fit <- NULL
 	try(fit <- do.call(fun, out), silent=TRUE)
-    # FitIndices <- inspect(fit, 'fit')
-	# Converged = TRUE
-	# if(sum(unlist(lapply(inspect(fit, "se"), sum))) == 0) Converged = FALSE
-	# params <- parameterEstimates(fit,standardized=T)
     return(fit)
 }
 	
-testMI <- function() {
-##Shamelessly using the example in lavaan
-
-test<-HolzingerSwineford1939[,-5]
-HS.model <- ' visual  =~ NA*x1 + x2 + x3
-               textual =~ NA*x4 + x5 + x6
-               speed   =~ NA*x7 + x8 + x9 
-			   visual ~~1*visual
-			   textual ~~ 1*textual
-			   speed ~~ 1*speed
-			   visual ~ speed'
-summary(cfa(HS.model,data=test), fit.measures=TRUE)
-
-test[(test$x6>3 && test$x6<4)]
-##Impose missing data to test
-log.mat1 <- matrix(FALSE, nrow=dim(test)[1], ncol=dim(test)[2])
-log.mat1[,9] <- test$x6>3
-test[log.mat1] <- NA
-
-runMI(test,HS.model,3, idvars='id')
-
-
-
-# fit@Options (May need to be changed some options)
-# fit@Model@GLIST
-# fit@Fit@est; fit@Fit@sd; fit@Fit@test 
-
-}
-
-
 #Conveniance function to run impuations on data and only return list of data
 imputeMissingAmelia <- function(data,m, miArgs){
   # pull out only the imputations
-  require(Amelia)
-  out <- c(list(amelia, x = data, m = m, p2s=0), miArgs)
+  library(Amelia)
+  out <- c(list(Amelia::amelia, x = data, m = m, p2s=0), miArgs)
   temp.am <- eval(as.call(out))
   return(temp.am$imputations)
 
@@ -286,12 +262,12 @@ imputeMissingAmelia <- function(data,m, miArgs){
 
 imputeMissingMice <- function(data,m, miArgs){
   # pull out only the imputations
-  require(mice)
-  out <- c(list(mice, data=data, m = m, diagnostics=FALSE, printFlag=FALSE), miArgs)
+  library(mice)
+  out <- c(list(mice::mice, data=data, m = m, diagnostics=FALSE, printFlag=FALSE), miArgs)
   temp.mice <- eval(as.call(out))
   temp.mice.imp <- NULL
   for(i in 1:m) {
-	temp.mice.imp[[i]] <- complete(x=temp.mice, action=i, include=FALSE) 
+	temp.mice.imp[[i]] <- mice::complete(x=temp.mice, action=i, include=FALSE) 
   }
   return(temp.mice.imp)
 } # end imputeMissingAmelia
@@ -407,16 +383,17 @@ lmrrPooledChi <- function(chis, df) {
 ## using the information in a lavaan object from the cfa function
 satPartable <- function(fit.alt){
   
-	par.alt<-partable(fit.alt) #get the parameter table form the original model
+	par.alt <- lavaan::partable(fit.alt) #get the parameter table form the original model
 	ngroups <- fit.alt@Data@ngroups # get the number of groups 
 	# gets the parameter table from the null model
-	par.null <- partable(lavaan:::independence.model.fit(fit.alt))
+	
+	par.null <- lavaan::lav_partable_independence(fit.alt)
 	lhs.diag <- par.null$lhs
 	op.diag <- par.null$op
 	rhs.diag <- par.null$rhs
 	gnull <- par.null$group
 	#combine the variable names to set al the covariances
-	pairs <- t(combn(lavaanNames(fit.alt, type="ov"), 2))
+	pairs <- t(combn(lavaan::lavaanNames(fit.alt, type="ov"), 2))
 	lhs.up <- rep(pairs[, 1],times=ngroups)
 	op.up <- rep("~~", length(lhs.up))
 	rhs.up <- rep(pairs[, 2],times=ngroups)
@@ -436,27 +413,31 @@ satPartable <- function(fit.alt){
 	unco <- id
 	par.sat <- list(id, lhs.all, op.all, rhs.all, user, group,
 				  free, ustart, exo, label, eq.id, unco)
-	names(par.sat)<-colnames(par.alt)
+	names(par.sat) <- c("id", "lhs", "op", "rhs", "user", "group", "free", "ustart", "exo", "label", "eq.id", "unco")
 	return(par.sat)
 }
 
 ##### function that does the part of the MR and Mplus combination methods are equal 
 mrplusPooledChi <- function(template, imputed.l, chi1, df, coef, m, fun, par.sat=NULL, ...) {
+	
 	if(is.null(par.sat)) par.sat <- satPartable(template)
-	comb.sat <- lapply(imputed.l, runlavaanMI, syntax=par.sat, fun=fun, ...)
+	comb.sat <- suppressWarnings(lapply(imputed.l, runlavaanMI, syntax=par.sat, fun=fun, ...))
+	converged.sat1 <- sapply(comb.sat, function(x) x@Fit@converged)
+	
 	coefs.sat1 <- sapply(comb.sat, function(x) x@Fit@est)
-	est.sat1 <- rowMeans(coefs.sat1)
+	est.sat1 <- rowMeans(coefs.sat1[,converged.sat1])
 	par.sat2 <- par.sat
 	par.sat2$free <- as.integer(rep(0, length(par.sat2$free)))
 	par.sat2$ustart <- est.sat1
-	comb.sat2 <- lapply(imputed.l, runlavaanMI, syntax=par.sat2, fun=fun, ...)
+	comb.sat2 <- suppressWarnings(lapply(imputed.l, runlavaanMI, syntax=par.sat2, fun=fun, ...))
+	
     comb.sat2 <- lapply(comb.sat2, forceTest)
 	fit.sat2 <- sapply(comb.sat2, function(x) inspect(x, "fit")["logl"])
-
-	par.alt2 <- partable(template)
+	
+	par.alt2 <- lavaan::partable(template)
 	par.alt2$free <- as.integer(rep(0, length(par.alt2$free)))
 	par.alt2$ustart <- coef
-	comb.alt2 <- lapply(imputed.l, runlavaanMI, syntax=par.alt2, fun=fun, ...)	
+	comb.alt2 <- suppressWarnings(lapply(imputed.l, runlavaanMI, syntax=par.alt2, fun=fun, ...))
     comb.alt2 <- lapply(comb.alt2, forceTest)
 	fit.alt2 <- sapply(comb.alt2, function(x) inspect(x, "fit")["logl"])
   	
@@ -474,7 +455,7 @@ mplusPooledChi <- function(chimean, k, ariv){
   comb.chi.mplus <- matrix(NA, nrow=1, ncol=3)
   comb.chi.mplus[1] <- chimean/(1+ariv)
   comb.chi.mplus[2] <- k
-  comb.chi.mplus[3] <- 1-pchisq(comb.chi.mplus[1], comb.chi.mplus[2])
+  comb.chi.mplus[3] <- 1 - pchisq(comb.chi.mplus[1], comb.chi.mplus[2])
   colnames(comb.chi.mplus) <- c("chisq", "df", "pvalue")
   comb.chi.mplus <- as.data.frame(comb.chi.mplus)
   rownames(comb.chi.mplus) <- ""
@@ -496,7 +477,7 @@ mrPooledChi <-function(chimean, m, k, ariv){
   comb.chi.mr[1] <- chimean/((1+ariv)*k)
   comb.chi.mr[2] <- k
   comb.chi.mr[3] <- v4
-  comb.chi.mr[4] <- 1-pf(comb.chi.mr[1], comb.chi.mr[2], comb.chi.mr[3])
+  comb.chi.mr[4] <- 1 - pf(comb.chi.mr[1], comb.chi.mr[2], comb.chi.mr[3])
   colnames(comb.chi.mr) <- c("F", "df1", "df2", "pvalue")
   comb.chi.mr <- as.data.frame(comb.chi.mr)
   rownames(comb.chi.mr) <- ""
@@ -504,43 +485,13 @@ mrPooledChi <-function(chimean, m, k, ariv){
 }
 
 forceTest <- function(object) {
-    # dirty hack to get a test statistic and fit measures from an
-    # unfitted model - YR 26 okt 2012
-
-    # create dummy x
-    x <- numeric(0L)
-    attr(x, "iterations") <- 0L;
-    attr(x, "converged") <- TRUE # forced!
-    attr(x, "control") <- object@Fit@control
-    attr(x, "fx") <- lavaan:::computeObjective(object@Model,
-                                   samplestats=object@SampleStats,
-                                   estimator=object@Options$estimator)
-    # get test statistic
-    TEST <- lavaan:::computeTestStatistic(object@Model,
-                                          partable=object@ParTable,
-                                          x=x,
-                                          options=object@Options,
-                                          samplestats=object@SampleStats,
-                                          data=object@Data)
-
-    lavaanFit <- lavaan:::Fit(partable = object@ParTable,
-                     start    = object@Fit@start,
-                     model    = object@Model,
-                     x        = x,
-                     VCOV     = NULL,
-                     TEST     = TEST)
-
-    lav <- new("lavaan",
-               call         = object@call,
-               timing       = object@timing,
-               Options      = object@Options,
-               ParTable     = object@ParTable,
-               Data         = object@Data,
-               SampleStats  = object@SampleStats,
-               Model        = object@Model,
-               Fit          = lavaanFit
-              )
-    lav
+	previousCall <- object@call
+	args <- as.list(previousCall[-1])
+	args$model <- lavaan::partable(object)
+	args$control <- list(optim.method="none", optim.force.converged=TRUE)
+	funcall <- as.character(previousCall[[1]])
+	lav <- do.call(funcall[length(funcall)], args)
+	lav
 }
 
 imposeGLIST <- function(object, coef, partable) {
@@ -554,7 +505,9 @@ imposeGLIST <- function(object, coef, partable) {
 		lhs <- partable$lhs[i]
 		rhs <- partable$rhs[i]
 		if(partable$op[i] == "=~") {
-			GLIST[names(GLIST) == "lambda"][[group]][rhs, lhs] <- coef[i]
+			targetName <- "lambda"
+			if(!(rhs %in% rownames(GLIST[names(GLIST) == "lambda"][[group]]))) targetName <- "beta"
+			GLIST[names(GLIST) == targetName][[group]][rhs, lhs] <- coef[i]
 		} else if (partable$op[i] == "~~") {
 			if(lhs %in% rownames(GLIST[names(GLIST) == "psi"][[group]])) {
 				GLIST[names(GLIST) == "psi"][[group]][rhs, lhs] <- coef[i]
